Welcome to Django Chuck’s documentation! — Django Chuck 0.1 documentation

### Navigation

- index
- next |
- Django Chuck 0.1 documentation »

# Welcome to Django Chuck’s documentation!

Django Chuck is a modular, open source, command-based project build system developed by Notch Interactive GmbH, that gives you the power to create new projects as fast as pushing on a button.

In the Django Chuck world, everything is organized within so-called modules, which incrementally get compiled into a project. There is really nothing that you can’t configure or adjust and guess what, writing and adjusting your modules is totally easy. On top of that, Django Chuck comes with an already impressive amount of built-in modules and a bullet proof project structure.

But Chuck cannot be just used to create a project. It can also checkout the source for you and setup everything until the dev server is up and running and you’re ready to do your development work. Just leave all the annoying stuff to Chuck and if there is some task Chuck can’t do for you at the moment you can add your own command to let Chuck configure your continuous integration system, setup your hosting or do whatever you might imagine!

Warning

Please note, that currently Django Chuck does NOT work on Windows machines. Please note further, that even though there are bindings to almost all important VC systems, only Git has been thoroughly tested.

## Getting Started

- 1. Installation
  - 1.1. Requirements
  - 1.2. Recommended
  - 1.3. Installation per pip
  - 1.4. Installation via source code
  - 1.5. Configuration
  - 1.6. Module aliases
- 2. Basic commands
  - 2.1. Build a new project
  - 2.2. Setup an existing project
- 3. Project structure
  - 3.1. Understanding the core module
- 4. Available modules
  - 4.1. A few words about...

## Customizations

- Configuring modules
  - Changing the default module set
- chuck_setup.py
- Writing templates
- Add your own modules
- Module dependencies
- Module post-build-actions
- Write your own command
- Write your own template engine

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- Django Chuck 0.1 documentation »